==> release-1.13.tar.gz: components-contrib/state/postgresql/v2/metadata.go <==
/*
Copyright 2023 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package postgresql

import (
	"errors"
	"time"

	pgauth "github.com/dapr/components-contrib/common/authentication/postgresql"
	"github.com/dapr/components-contrib/state"
	"github.com/dapr/kit/metadata"
	"github.com/dapr/kit/ptr"
)

type pgTable string

const (
	pgTableState pgTable = "state"
)

const (
	defaultCleanupInternal = time.Hour
	defaultTimeout         = 20 * time.Second // Default timeout for network requests
)

type pgMetadata struct {
	pgauth.PostgresAuthMetadata `mapstructure:",squash"`

	TablePrefix       string         `mapstructure:"tablePrefix"`       // Could be in the format "schema.table" or just "table"
	MetadataTableName string         `mapstructure:"metadataTableName"` // Could be in the format "schema.table" or just "table"
	Timeout           time.Duration  `mapstructure:"timeout" mapstructurealiases:"timeoutInSeconds"`
	CleanupInterval   *time.Duration `mapstructure:"cleanupInterval" mapstructurealiases:"cleanupIntervalInSeconds"`
}

func (m *pgMetadata) InitWithMetadata(meta state.Metadata, azureADEnabled bool) error {
	// Reset the object
	m.PostgresAuthMetadata.Reset()
	m.TablePrefix = ""
	m.MetadataTableName = "dapr_metadata"
	m.CleanupInterval = ptr.Of(defaultCleanupInternal)
	m.Timeout = defaultTimeout

	// Decode the metadata
	err := metadata.DecodeMetadata(meta.Properties, &m)
	if err != nil {
		return err
	}

	// Validate and sanitize input
	err = m.PostgresAuthMetadata.InitWithMetadata(meta.Properties, azureADEnabled)
	if err != nil {
		return err
	}

	// Timeout
	if m.Timeout < 1*time.Second {
		return errors.New("invalid value for 'timeout': must be greater than 1s")
	}

	// Cleanup interval
	// Non-positive value from meta means disable auto cleanup.
	// We need to do this check because an empty string and "0" are treated differently by DecodeMetadata
	v, ok := meta.GetProperty("cleanupInterval", "cleanupIntervalInSeconds")
	if ok && v == "" {
		// Handle the case of an empty string, but present
		m.CleanupInterval = ptr.Of(defaultCleanupInternal)
	} else if (ok && v == "0") || (m.CleanupInterval != nil && *m.CleanupInterval <= 0) {
		m.CleanupInterval = nil
	}

	return nil
}

func (m pgMetadata) TableName(table pgTable) string {
	return m.TablePrefix + string(table)
}

==> release-1.14.tar.gz: components-contrib/state/postgresql/v2/metadata.go <==
/*
Copyright 2023 The Dapr Authors
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package postgresql

import (
	"errors"
	"time"

	"github.com/dapr/components-contrib/common/authentication/aws"
	pgauth "github.com/dapr/components-contrib/common/authentication/postgresql"
	"github.com/dapr/components-contrib/state"
	"github.com/dapr/kit/metadata"
	"github.com/dapr/kit/ptr"
)

type pgTable string

const (
	pgTableState pgTable = "state"
)

const (
	defaultCleanupInternal = time.Hour
	defaultTimeout         = 20 * time.Second // Default timeout for network requests
)

type pgMetadata struct {
	pgauth.PostgresAuthMetadata `mapstructure:",squash"`

	TablePrefix       string         `mapstructure:"tablePrefix"`       // Could be in the format "schema.table" or just "table"
	MetadataTableName string         `mapstructure:"metadataTableName"` // Could be in the format "schema.table" or just "table"
	Timeout           time.Duration  `mapstructure:"timeout" mapstructurealiases:"timeoutInSeconds"`
	CleanupInterval   *time.Duration `mapstructure:"cleanupInterval" mapstructurealiases:"cleanupIntervalInSeconds"`

	aws.AWSIAM `mapstructure:",squash"`
}

func (m *pgMetadata) InitWithMetadata(meta state.Metadata, opts pgauth.InitWithMetadataOpts) error {
	// Reset the object
	m.PostgresAuthMetadata.Reset()
	m.TablePrefix = ""
	m.MetadataTableName = "dapr_metadata"
	m.CleanupInterval = ptr.Of(defaultCleanupInternal)
	m.Timeout = defaultTimeout

	// Decode the metadata
	err := metadata.DecodeMetadata(meta.Properties, &m)
	if err != nil {
		return err
	}

	// Validate and sanitize input
	err = m.PostgresAuthMetadata.InitWithMetadata(meta.Properties, opts)
	if err != nil {
		return err
	}

	// Timeout
	if m.Timeout < 1*time.Second {
		return errors.New("invalid value for 'timeout': must be greater than 1s")
	}

	// Cleanup interval
	// Non-positive value from meta means disable auto cleanup.
	// We need to do this check because an empty string and "0" are treated differently by DecodeMetadata
	v, ok := meta.GetProperty("cleanupInterval", "cleanupIntervalInSeconds")
	if ok && v == "" {
		// Handle the case of an empty string, but present
		m.CleanupInterval = ptr.Of(defaultCleanupInternal)
	} else if (ok && v == "0") || (m.CleanupInterval != nil && *m.CleanupInterval <= 0) {
		m.CleanupInterval = nil
	}

	return nil
}

func (m pgMetadata) TableName(table pgTable) string {
	return m.TablePrefix + string(table)
}
